@@ -50,7 +50,7 @@ class OSClientManager(object):
         if 'verify' in kwargs.keys():
             session_kwargs['verify'] = kwargs.pop('verify')
         if 'cacert' in kwargs.keys():
-            session_kwargs['cert'] = kwargs.pop('cacert')
+            session_kwargs['verify'] = kwargs.pop('cacert')
         # client specific args
         if 'insecure' in kwargs.keys():
             self.client_kwargs['insecure'] = kwargs.pop('insecure')
@@ -118,16 +118,16 @@ class OSClientManager(object):
         if 'region_name' in self.swift_args.keys():
             os_options['region_name'] = self.swift_args.get('region_name')
         if 'endpoint_type' in self.swift_args.keys():
-            os_options['endpoint_type'] = self.swift_args.pop('endpoint_type')
+            os_options['endpoint_type'] = self.swift_args.get('endpoint_type')
         if 'tenant_id' in self.swift_args.keys():
-            os_options['tenant_id'] = self.swift_args.pop('tenant_id')
+            os_options['tenant_id'] = self.swift_args.get('tenant_id')
         if 'identity_api_version' in self.swift_args.keys():
             os_options['identity_api_version'] = \
-                self.swift_args.pop('identity_api_version')
+                self.swift_args.get('identity_api_version')
             auth_version = os_options['identity_api_version']
 
         if 'token' in self.swift_args.keys():
-            os_options['auth_token'] = self.swift_args.pop('token')
+            os_options['auth_token'] = self.swift_args.get('token')
         if 'auth_version' in self.swift_args.keys():
             auth_version = self.swift_args.get('auth_version')
         os_options['project_domain_name'] = \
@@ -284,7 +284,8 @@ class OSClientManager(object):
         LOG.debug("Download image enter")
         stream = self.get_glance().images.data(image.id)
         LOG.debug("Stream with size {0}".format(image.size))
-        return utils.ReSizeStream(stream, image.size, 1000000)
+        return utils.ReSizeStream(stream, image.size,
+                                  CONF.get('max_segment_size'))
 
     def create_image(self, name, container_format, disk_format, data=None):
         LOG.info("Creating glance image")
