@@ -16,34 +16,42 @@ limitations under the License.
 """
 
 import json
-from oslo_log import log
-import requests.exceptions
+import os
 import time
 
+from oslo_log import log
+import requests
+from requests.packages.urllib3.exceptions import InsecureRequestWarning
+
 from freezer.storage import physical
 
 LOG = log.getLogger(__name__)
 
+requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
+
 
 class SwiftStorage(physical.PhysicalStorage):
     """
     :type client_manager: freezer.osclients.ClientManager
     """
 
+    _type = 'swift'
+
     def rmtree(self, path):
         split = path.rsplit('/', 1)
         for file in self.swift().get_container(split[0],
                                                prefix=split[1])[1]:
             try:
                 self.swift().delete_object(split[0], file['name'])
-            except Exception as e:
-                raise e
+            except Exception:
+                raise
 
     def put_file(self, from_path, to_path):
-        self.client_manager.create_swift()
         split = to_path.rsplit('/', 1)
+        file_size = os.path.getsize(from_path)
         with open(from_path, 'r') as meta_fd:
-            self.swift().put_object(split[0], split[1], meta_fd)
+            self.swift().put_object(split[0], split[1], meta_fd,
+                                    content_length=file_size)
 
     def __init__(self, client_manager, container, max_segment_size,
                  skip_prepare=False):
@@ -64,7 +72,7 @@ class SwiftStorage(physical.PhysicalStorage):
         :rtype: swiftclient.Connection
         :return:
         """
-        return self.client_manager.get_swift()
+        return self.client_manager.create_swift()
 
     def upload_chunk(self, content, path):
         """
@@ -79,20 +87,19 @@ class SwiftStorage(physical.PhysicalStorage):
         split = path.rsplit('/', 1)
         while not success:
             try:
-                LOG.info(
+                LOG.debug(
                     'Uploading file chunk index: {0}'.format(path))
                 self.swift().put_object(
                     split[0], split[1], content,
                     content_type='application/octet-stream',
                     content_length=len(content))
-                LOG.info('Data successfully uploaded!')
+                LOG.debug('Data successfully uploaded!')
                 success = True
             except Exception as error:
                 LOG.info(
                     'Retrying to upload file chunk index: {0}'.format(
                         path))
                 time.sleep(60)
-                self.client_manager.create_swift()
                 count += 1
                 if count == 10:
                     LOG.critical('Error: add_object: {0}'
@@ -107,7 +114,6 @@ class SwiftStorage(physical.PhysicalStorage):
         :type backup: freezer.storage.base.Backup
         """
         backup = backup.copy(storage=self)
-        self.client_manager.create_swift()
         headers = {'x-object-manifest': backup.segments_path}
         LOG.info('[*] Uploading Swift Manifest: {0}'.format(backup))
         split = backup.data_path.rsplit('/', 1)
@@ -165,13 +171,12 @@ class SwiftStorage(physical.PhysicalStorage):
 
         full_path = "{0}/{1}".format(backup_basepath, package_name)
         headers['x-object-manifest'] = full_path
-        headers['x-object-meta-length'] = str(len(stream))
 
         objname = package_name.rsplit('/', 1)[1]
         # This call sets the metadata on a file which will be used to download
         # the whole backup later. Do not remove it ! (szaher)
         self.swift().put_object(container=full_path, obj=objname, contents=u'',
-                                headers=headers)
+                                content_length=len(u''), headers=headers)
 
     def backup_blocks(self, backup):
         """
@@ -182,12 +187,12 @@ class SwiftStorage(physical.PhysicalStorage):
         """
         split = backup.data_path.split('/', 1)
         try:
-            chunks = self.client_manager.create_swift().get_object(
+            chunks = self.swift().get_object(
                 split[0], split[1],
                 resp_chunk_size=self.max_segment_size)[1]
         except requests.exceptions.SSLError as e:
             LOG.warning(e)
-            chunks = self.client_manager.create_swift().get_object(
+            chunks = self.swift().get_object(
                 split[0], split[1],
                 resp_chunk_size=self.max_segment_size)[1]
 
